@@ -9,15 +9,15 @@ def getGoogleNewsLink(start,end,counts, keystring):
     start: start date
     end: last date
     counts: how many pages you want to turn
-    keystring: "nasdaq AND eur"
+    keystring: "nasdaq AND eur  1"
     '''
     googlenews=GoogleNews(start=start,end=end)
     googlenews.search(keystring)
     for i in range(0,counts):
         googlenews.getpage(i)
         result=googlenews.result() 
-        df=pd.DataFrame(result)
-    return df
+       
+    return pd.DataFrame(result)
 
 def getGoogleNewsArticle(gnews):
     '''
